# Gavia

## Usage Examples 

### Notebooks

* Logs 
    * <a href="http://nbviewer.ipython.org/github/brett-hosking/gavia/blob/master/examples/notebooks/load_gavia_logs.ipynb" target="_blank">Parse/Load logs</a> 

* Images 
    * <a href="http://nbviewer.ipython.org/github/brett-hosking/gavia/blob/master/examples/notebooks/load_and_save_images.ipynb" target="_blank">Load and Save</a> 